==> php-phalcon4_4.1.3.orig.tar.gz: cphalcon-4.1.3/BACKERS.md <==
## Our Backers and supporters

You can join them in supporting Phalcon and Zephir development by visiting our page on [Open Collective](https://opencollective.com/phalcon) or [Github sponsor](https://phalcon.io/fund) and becoming a sponsor or a backer!

### Supporters

<table>
  <tbody>
    <tr>
      <td align="center" valign="bottom">
        <a href="https://mctekk.com">
          <img width="222px" height="32px" src="https://assets.phalcon.io/phalcon/images/backers/mctekk-149x34.svg" style="max-width:100%; vertical-align: bottom;" alt="mctekk">
        </a>
      </td>
      <td align="center" valign="bottom">
        <a href="https://www.cloudflare.com/">
          <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/cloudflare.svg" style="max-width:100%;" alt="Cloudflare">
        </a>
      </td>
      <td align="center" valign="bottom">
        <a href="https://abits.com">
          <img width="222px" height="36px" src="https://assets.phalcon.io/phalcon/images/backers/abits-100x34.svg" style="max-width:100%;" alt="Abits">
        </a>
      </td>
      <td align="center" valign="bottom">
        <a href="https://algolia.com">
          <img width="222px" height="34px" src="https://assets.phalcon.io/phalcon/images/backers/algolia-725x360.svg" style="max-width:100%;" alt="Algolia">
        </a>
      </td>
    </tr>
    <tr>
    <td align="center" valign="bottom">
        <a href="https://netlify.com">
          <img width="222px" height="36px" src="https://assets.phalcon.io/phalcon/images/backers/netlify-147x40.svg" style="max-width:100%;" alt="Netlify">
        </a>
     </td>
      <td align="center" valign="bottom">
        <a href="https://odva.pro/">
          <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/o2.svg" style="max-width:100%;" alt="o2">
        </a>
      </td>
    <td align="center" valign="bottom">   
      <a href="https://crowdin.com/">
        <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/crowdin.png" style="max-width:100%;" alt="Crowdin">
      </a>
    </td>
     <td align="center" valign="bottom">   
      <a href="https://www.uptrends.com">
        <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/uptrends-200x60.svg" style="max-width:100%;" alt="Uptrends Web Application Monitoring">
      </a>
    </td>
    </tr>
    <tr>
    <td align="center" valign="bottom">   
      <a href="https://phalcon.io/fund">
       Support Us
      </a>
    </td>
    </tr>
  </tbody>
</table>

### Sponsors
Become a sponsor and get your logo on our README on Github with a link to your site. [[Become a sponsor](https://opencollective.com/phalcon#sponsor)]

<a href="https://opencollective.com/phalcon/#contributors">
<img src="https://opencollective.com/phalcon/tiers/sponsors.svg?avatarHeight=48&width=800">
</a>

### Backers
Support us with a monthly donation and help us continue our activities. [[Become a backer](https://opencollective.com/phalcon#backer)]

<a href="https://opencollective.com/phalcon/#contributors">
<img src="https://opencollective.com/phalcon/tiers/backers.svg?avatarHeight=48&width=800&height=200">
</a>

## Github sponsors

Thanks for the support

[//]: github-sponsors

<a href="https://github.com/evansims"><img src="https://avatars2.githubusercontent.com/u/3093?s=460&u=cfba72529ae60e76c15dca111246baea93e333a7&v=4" title="Evan Sims" width="60" height="60"></a>
<a href="https://github.com/ninjapanzer"><img src="https://avatars1.githubusercontent.com/u/159591?s=460&v=4" title="Paul Scarrone" width="60" height="60"></a>
<a href="https://github.com/vlad-light"><img src="https://avatars1.githubusercontent.com/u/277235?s=460&v=4" title="Vladimir L" width="60" height="60"></a>
<a href="https://github.com/alrieckert"><img src="https://avatars1.githubusercontent.com/u/452786?s=460&v=4" title="Anton Rieckert" width="60" height="60"></a>
<a href="https://github.com/yannux"><img src="https://avatars.githubusercontent.com/u/533125?s=460&u=4f1e888783d1faafaa76282e5c388501c2b2df83&v=4" title="Yann" width="60" height="60"></a>
<a href="https://github.com/sinbadxiii"><img src="https://avatars2.githubusercontent.com/u/900273?s=460&v=4" title="Sergey Mukhin" width="60" height="60"></a>
<a href="https://github.com/pfz"><img src="https://avatars2.githubusercontent.com/u/1042926?s=460&u=2ef2c7abef6e873562b3fa10dbab56fc046e04f1&v=4" title="Francois Paulin" width="60" height="60"></a>
<a href="https://github.com/niden"><img src="https://avatars2.githubusercontent.com/u/1073784?s=460&v=4" title="Nikolaos Dimopoulos" width="60" height="60"></a>
<a href="https://github.com/qmegas"><img src="https://avatars3.githubusercontent.com/u/2444896?s=460&v=4" title="qmegas" width="60" height="60"></a>
<a href="https://github.com/gwijnja"><img src="https://avatars1.githubusercontent.com/u/2666867?s=460&u=7f358f88d53208909d808db17b382ae44d9eb48a&v=4" title="Gerben Wijnja" width="60" height="60"></a>
<a href="https://github.com/terolblade"><img src="https://avatars3.githubusercontent.com/u/3078649?s=460&v=4" title="Stanislav Sviridenko" width="60" height="60"></a>
<a href="https://github.com/Ruzgfpegk"><img src="https://avatars1.githubusercontent.com/u/3818364?s=460&v=4" title="Ruzgfpegk" width="60" height="60"></a>
<a href="https://github.com/zsilbi"><img src="https://avatars2.githubusercontent.com/u/3886658?s=460&v=4" title="Balázs Németh" width="60" height="60"></a>
<a href="https://github.com/RayHughes"><img src="https://avatars3.githubusercontent.com/u/4381883?s=460&u=16dbf2e3fbfae0892a858d6d4cc8869bfde6dd74&v=4" title="Ray Hughes" width="60" height="60"></a>
<a href="https://github.com/borisdelev"><img src="https://avatars.githubusercontent.com/u/4441663?s=460&u=be604c39153e26326f2123c6e1bfe880d5ec0947&v=4" title="Boris Delev" width="60" height="60"></a>
<a href="https://github.com/educury"><img src="https://avatars2.githubusercontent.com/u/5339278?s=460&v=4" title="educury" width="60" height="60"></a>
<a href="https://github.com/emagus"><img src="https://avatars3.githubusercontent.com/u/5857789?s=460&v=4" title="emagus" width="60" height="60"></a>
<a href="https://github.com/ruudboon"><img src="https://avatars3.githubusercontent.com/u/7444246?s=460&v=4" title="Ruud Boon" width="60" height="60"></a>
<a href="https://github.com/sitchi"><img src="https://avatars0.githubusercontent.com/u/11546683?s=460&v=4" title="Nikoloz Sitchinava" width="60" height="60"></a>
<a href="https://github.com/tacxticx88"><img src="https://avatars3.githubusercontent.com/u/12997062?s=460&u=5af0fbe438391ac46fb19befe0c20a4b1374e187&v=4" title="Clément" width="60" height="60"></a>
<a href="https://github.com/Montana"><img src="https://avatars3.githubusercontent.com/u/20936398?s=460&v=4" title="Montana Mendy" width="60" height="60"></a>
<a href="https://github.com/fvromera"><img src="https://avatars.githubusercontent.com/u/32909196?s=460&u=a4a6d765c836be52ab247354399d0ed1a49224fa&v=4" title="fvromera" width="60" height="60"></a>
<a href="https://github.com/ak1113"><img src="https://avatars0.githubusercontent.com/u/38716832?s=460&v=4" title="Akira Kato" width="60" height="60"></a>
<a href="https://github.com/dredasss"><img src="https://avatars1.githubusercontent.com/u/38747389?s=460&u=ee99a8bb28ee6bedbbea6325d49d4eb99080d421&v=4" title="Nerijus Alex" width="60" height="60"></a>

[//]: github-sponsors

## Core Team
[Ruud](https://github.com/ruudboon), [Nikolaos](https://github.com/niden), [Serghei](https://github.com/sergeyklay)

==> php-phalcon5_5.1.2.orig.tar.gz: cphalcon-5.1.2/BACKERS.md <==
## Our Backers and supporters

You can join them in supporting Phalcon and Zephir development by visiting our page on [Open Collective](https://opencollective.com/phalcon) or [Github sponsor](https://phalcon.io/fund) and becoming a sponsor or a backer!

### Supporters

<table>
  <tbody>
    <tr>
      <td align="center" valign="bottom">
        <a href="https://mctekk.com">
          <img width="222px" height="32px" src="https://assets.phalcon.io/phalcon/images/backers/mctekk-149x34.svg" style="max-width:100%; vertical-align: bottom;" alt="mctekk">
        </a>
      </td>
      <td align="center" valign="bottom">
        <a href="https://www.cloudflare.com/">
          <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/cloudflare.svg" style="max-width:100%;" alt="Cloudflare">
        </a>
      </td>
      <td align="center" valign="bottom">
        <a href="https://abits.com">
          <img width="222px" height="36px" src="https://assets.phalcon.io/phalcon/images/backers/abits-100x34.svg" style="max-width:100%;" alt="Abits">
        </a>
      </td>
      <td align="center" valign="bottom">
        <a href="https://algolia.com">
          <img width="222px" height="34px" src="https://assets.phalcon.io/phalcon/images/backers/algolia-725x360.svg" style="max-width:100%;" alt="Algolia">
        </a>
      </td>
    </tr>
    <tr>
    <td align="center" valign="bottom">
        <a href="https://netlify.com">
          <img width="222px" height="36px" src="https://assets.phalcon.io/phalcon/images/backers/netlify-147x40.svg" style="max-width:100%;" alt="Netlify">
        </a>
     </td>
      <td align="center" valign="bottom">
        <a href="https://odva.pro/">
          <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/o2.svg" style="max-width:100%;" alt="o2">
        </a>
      </td>
    <td align="center" valign="bottom">   
      <a href="https://crowdin.com/">
        <img width="222px" height="auto" src="https://assets.phalcon.io/phalcon/images/backers/crowdin.png" style="max-width:100%;" alt="Crowdin">
      </a>
    </td>
     <td align="center" valign="bottom">   
      <a href="https://www.uptrends.com">
        <img width="222px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/uptrends-200x60.svg" style="max-width:100%;" alt="Uptrends Web Application Monitoring">
      </a>
    </td>
    </tr>
    <tr>
    <td align="center" valign="bottom">   
      <a href="https://www.digitalocean.com/">
        <img width="170px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/digitalocean.svg" style="max-width:100%;" alt="DigitalOcean open source">
      </a>
    </td>
     <td align="center" valign="bottom">   
      <a href="https://packagecloud.io/">
        <img width="170px" height="auto" src="https://assets.phalcon.io/phalcon/images/backers/packagecloud.png" style="max-width:100%;" alt="Private NPM registry and Maven, RPM, DEB, PyPi and RubyGem Repository · packagecloud">
      </a>
    </td>
     <td align="center" valign="bottom">   
      <a href="https://www.postype.com/">
        <img width="170px" height="40px" src="https://assets.phalcon.io/phalcon/images/backers/postype.svg" style="max-width:100%;" alt="https://www.postype.com/">
      </a>
    </td>
    <td align="center" valign="center">   
      <a href="https://phalcon.io/fund">
       Support Us
      </a>
    </td>
    </tr>
  </tbody>
</table>

### Sponsors
Become a sponsor and get your logo on our README on Github with a link to your site. [[Become a sponsor](https://opencollective.com/phalcon#sponsor)]

<a href="https://opencollective.com/phalcon/#contributors">
<img src="https://opencollective.com/phalcon/tiers/sponsors.svg?avatarHeight=48&width=800">
</a>

### Backers
Support us with a monthly donation and help us continue our activities. [[Become a backer](https://opencollective.com/phalcon#backer)]

<a href="https://opencollective.com/phalcon/#contributors">
<img src="https://opencollective.com/phalcon/tiers/backers.svg?avatarHeight=48&width=800&height=200">
</a>

## Github sponsors

Thanks for the support

[//]: github-sponsors

<a href="https://github.com/niden"><img src="https://avatars2.githubusercontent.com/u/1073784?s=460&v=4" title="Nikolaos Dimopoulos" width="60" height="60"></a>
<a href="https://github.com/Brade"><img src="https://avatars.githubusercontent.com/u/46009?v=4" title="N. Brad Garrett" width="60" height="60"></a>
<a href="https://github.com/DestinyMKas"><img src="https://avatars.githubusercontent.com/u/170159?v=4" title="Karolis Mačiulskis" width="60" height="60"></a>
<a href="https://github.com/andresgutierrez"><img src="https://avatars.githubusercontent.com/u/213590?v=4" title="Andres Gutierrez" width="60" height="60"></a>
<a href="https://github.com/pyatin"><img src="https://avatars.githubusercontent.com/u/296939?v=4" title="Glib Pyatin" width="60" height="60"></a>
<a href="https://github.com/alrieckert"><img src="https://avatars1.githubusercontent.com/u/452786?s=460&v=4" title="Anton Rieckert" width="60" height="60"></a>
<a href="https://github.com/yannux"><img src="https://avatars.githubusercontent.com/u/533125?s=460&u=4f1e888783d1faafaa76282e5c388501c2b2df83&v=4" title="Yann" width="60" height="60"></a>
<a href="https://github.com/elcreator"><img src="https://avatars.githubusercontent.com/u/974975?v=4" title="Artur Kyryliuk" width="60" height="60"></a>
<a href="https://github.com/Ultimater"><img src="https://avatars.githubusercontent.com/u/1922199?v=4" title="Kevin Yarmak" width="60" height="60"></a>
<a href="https://github.com/qmegas"><img src="https://avatars3.githubusercontent.com/u/2444896?s=460&v=4" title="qmegas" width="60" height="60"></a>
<a href="https://github.com/Ruzgfpegk"><img src="https://avatars1.githubusercontent.com/u/3818364?s=460&v=4" title="Ruzgfpegk" width="60" height="60"></a>
<a href="https://github.com/f-do"><img src="https://avatars.githubusercontent.com/u/4299065?v=4" title="Florian" width="60" height="60"></a>
<a href="https://github.com/borisdelev"><img src="https://avatars.githubusercontent.com/u/4441663?s=460&u=be604c39153e26326f2123c6e1bfe880d5ec0947&v=4" title="Boris Delev" width="60" height="60"></a>
<a href="https://github.com/stdnk"><img src="https://avatars.githubusercontent.com/u/5130969?v=4" title="Vasily Stadnik" width="60" height="60"></a>
<a href="https://github.com/educury"><img src="https://avatars2.githubusercontent.com/u/5339278?s=460&v=4" title="educury" width="60" height="60"></a>
<a href="https://github.com/emagus"><img src="https://avatars.githubusercontent.com/u/5857789?v=4" title="maGus Informática" width="60" height="60"></a>
<a href="https://github.com/tztztztz"><img src="https://avatars.githubusercontent.com/u/7032308?v=4" title="Tomasz Zadora" width="60" height="60"></a>
<a href="https://github.com/ruudboon"><img src="https://avatars3.githubusercontent.com/u/7444246?s=460&v=4" title="Ruud Boon" width="60" height="60"></a>
<a href="https://github.com/sitchi"><img src="https://avatars.githubusercontent.com/u/11546683?v=4" title="Nikoloz Sitchinava" width="60" height="60"></a>
<a href="https://github.com/6trading"><img src="https://avatars.githubusercontent.com/u/12135941?v=4" title="Chris" width="60" height="60"></a>
<a href="https://github.com/Montana"><img src="https://avatars3.githubusercontent.com/u/20936398?s=460&v=4" title="Montana Mendy" width="60" height="60"></a>
<a href="https://github.com/fvromera"><img src="https://avatars.githubusercontent.com/u/32909196?s=460&u=a4a6d765c836be52ab247354399d0ed1a49224fa&v=4" title="fvromera" width="60" height="60"></a>
<a href="https://github.com/ak1113"><img src="https://avatars0.githubusercontent.com/u/38716832?s=460&v=4" title="Akira Kato" width="60" height="60"></a>
<a href="https://github.com/dredasss"><img src="https://avatars1.githubusercontent.com/u/38747389?s=460&u=ee99a8bb28ee6bedbbea6325d49d4eb99080d421&v=4" title="Nerijus Alex" width="60" height="60"></a>
<a href="https://github.com/RaulRaf95"><img src="https://avatars.githubusercontent.com/u/63474503?v=4" title="RaulRaf95" width="60" height="60"></a>
<a href="https://github.com/levertr"><img src="https://avatars.githubusercontent.com/u/78140431?v=4" title="Rayan Levert" width="60" height="60"></a>
<a href="https://github.com/iogates"><img src="https://avatars.githubusercontent.com/u/86652317?s=200&v=4" title="iogates" width="60" height="60"></a>
<a href="https://github.com/super-dmitriy"><img src="https://avatars.githubusercontent.com/u/5605919?v=4" title="Dmitriy" width="60" height="60"></a>

[//]: github-sponsors

## Core Team
[Ruud](https://github.com/ruudboon), [Nikolaos](https://github.com/niden), [Serghei](https://github.com/sergeyklay)
